
#ifndef EL__MIME_BACKEND_MIMETYPES_H
#define EL__MIME_BACKEND_MIMETYPES_H

#include "main/module.h"
#include "mime/backend/common.h"

extern struct mime_backend mimetypes_mime_backend;
extern struct module mimetypes_mime_module;

#endif
